@@ -92,15 +92,36 @@ class DescribeStreamConsumerRequest : public KinesisRequest {
     return *this;
   }
   ///@}
+
+  ///@{
+  /**
+   * <p>Not Implemented. Reserved for future use.</p>
+   */
+  inline const Aws::String& GetStreamId() const { return m_streamId; }
+  inline bool StreamIdHasBeenSet() const { return m_streamIdHasBeenSet; }
+  template <typename StreamIdT = Aws::String>
+  void SetStreamId(StreamIdT&& value) {
+    m_streamIdHasBeenSet = true;
+    m_streamId = std::forward<StreamIdT>(value);
+  }
+  template <typename StreamIdT = Aws::String>
+  DescribeStreamConsumerRequest& WithStreamId(StreamIdT&& value) {
+    SetStreamId(std::forward<StreamIdT>(value));
+    return *this;
+  }
+  ///@}
  private:
   Aws::String m_streamARN;
 
   Aws::String m_consumerName;
 
   Aws::String m_consumerARN;
+
+  Aws::String m_streamId;
   bool m_streamARNHasBeenSet = false;
   bool m_consumerNameHasBeenSet = false;
   bool m_consumerARNHasBeenSet = false;
+  bool m_streamIdHasBeenSet = false;
 };
 
 }  // namespace Model
