@@ -71,6 +71,24 @@ class UpdateStreamWarmThroughputRequest : public KinesisRequest {
   }
   ///@}
 
+  ///@{
+  /**
+   * <p>Not Implemented. Reserved for future use.</p>
+   */
+  inline const Aws::String& GetStreamId() const { return m_streamId; }
+  inline bool StreamIdHasBeenSet() const { return m_streamIdHasBeenSet; }
+  template <typename StreamIdT = Aws::String>
+  void SetStreamId(StreamIdT&& value) {
+    m_streamIdHasBeenSet = true;
+    m_streamId = std::forward<StreamIdT>(value);
+  }
+  template <typename StreamIdT = Aws::String>
+  UpdateStreamWarmThroughputRequest& WithStreamId(StreamIdT&& value) {
+    SetStreamId(std::forward<StreamIdT>(value));
+    return *this;
+  }
+  ///@}
+
   ///@{
   /**
    * <p>The target warm throughput in MB/s that the stream should be scaled to
@@ -93,9 +111,12 @@ class UpdateStreamWarmThroughputRequest : public KinesisRequest {
 
   Aws::String m_streamName;
 
+  Aws::String m_streamId;
+
   int m_warmThroughputMiBps{0};
   bool m_streamARNHasBeenSet = false;
   bool m_streamNameHasBeenSet = false;
+  bool m_streamIdHasBeenSet = false;
   bool m_warmThroughputMiBpsHasBeenSet = false;
 };
 
